## Download Data
############################################################################################
rm -r species-data
mkdir species-data
mkdir tmp
cd tmp
for F in $(grep -v "#" ../SPECIES); do echo $F; wget "ftp://ftp.ncbi.nih.gov/genomes/Bacteria/$F/*.fna"; cat *.fna >"../species-data/$F.fna"; rm -f *.fna; done
for F in $(grep -v "#" ../SPECIES); do echo $F; wget "ftp://ftp.ncbi.nih.gov/genomes/Bacteria/$F/*.faa"; cat *.faa >"../species-data/$F.faa"; rm -f *.faa; done
for F in $(grep -v "#" ../SPECIES); do echo $F; wget "ftp://ftp.ncbi.nih.gov/genomes/Bacteria/$F/*.gff"; cat *.gff >"../species-data/$F.gff"; rm -f *.gff; done
cd ..
rm -r tmp

## Run Proteinortho (v5)
############################################################################################
./tools/proteinortho/proteinortho5.pl -e=1e-10 -keep -project=species -sim=0.9 species-data/*.faa

## Copy .bla files to blast folder
############################################################################################
rm -r blast
mkdir blast
mv *.bla blast/

## Reblast all groups to enhance annotation
############################################################################################
head -n1 species.proteinortho > reblast_us.out
# 11 = number of species
awk '{if($1 < 11){print $0}}' species.proteinortho | sort -k1nr >> reblast_us.out

rm -r reblast
mkdir reblast
cd reblast

# Fetch proteins from faa files
../tools/grab_proteins.pl -genomes=../species-data -proteins=../species-data ../reblast_us.out

# Some stats about where most stuff is missing
awk '{print $2}' reblast.job | sort | uniq -c | sort -nr > missing.stats

# Blast for missing stuff
../tools/reblast.pl reblast.job > blast.jobs
sh blast.jobs

## Enhance annotation based on reblast
############################################################################################
rm *.add.gff *.add.faa
../tools/detect_reblasted.pl reblast.job

# Merge enhanced annotation
cd ..
rm -r enhanced
mkdir enhanced
cd  enhanced
../tools/merge_enhanced.pl ../species-data/*.faa ../reblast/
for F in *.faa; do ../tools/convertseq.pl -i=fasta -o=fasta $F > tmp; mv tmp $F; done
cd ..

## Run Proteinortho with the enhanced set
############################################################################################
./tools/proteinortho/proteinortho5.pl -e=1e-10 -keep -project=species_enhanced -sim=0.9 enhanced/*.faa

rm -r blast_enhanced
mkdir blast_enhanced
mv *.bla blast_enhanced/

rm -r proteinortho
mkdir proteinortho
mv species.* proteinortho/
mv species_enhanced.* proteinortho/
mv reblast_us.out proteinortho/
