#!/usr/bin/perl

## Grabs proteins and tells missing species from groups
use strict;
use warnings;

my $proteins_path = "./";
my $genomes_path = "./";

unless (scalar(@ARGV)) {

	print STDERR "Prepares reblast jobs for a given proteinortho output file\n -proteins=[PATH2PROTEINS]\n-genomes==[PATH2PROTEINS]\n";
	exit;
}

foreach (@ARGV) {
	if 	($_ =~ /-proteins=(.+)/) 	{ $proteins_path = $1; }
	elsif 	($_ =~ /-genomes=(.+)/) 	{ $genomes_path = $1; }
}

my @paths = ();
my $line = -2;
my %genomes;
open(REBLAST,">reblast.job");
my $file = pop(@ARGV);
open(IN,"<$file") || die ("Could not open '$file': $!");
while(<IN>){
	$line++;
	print STDERR "Set $line...\n";
	chomp;
	my @data = split(/\t+/,$_);
	if ($line == -1) {
		@paths = @data;		# no we know the file for each entry
		my $error = 0;
		print STDERR "Loading Genomes...\n";
		for (my $i = 3; $i < scalar(@paths); $i++) {
			my $genome = $paths[$i];
			$genome =~ s/\....?$/\.fna/;
			if (!-e "$proteins_path/$paths[$i]") 	{$error++; print STDERR "Could not find PROTEINs for '$proteins_path/$paths[$i]'\n";}
			if (!-e "$genomes_path/$genome") 	{$error++; print STDERR "Could not find GENOME for   '$proteins_path/$genome'\n";}
			
			system("formatdb -i $genomes_path/$genome -p F -o F");

			my %hash = fasta2hash("$proteins_path/$paths[$i]",1);
			$genomes{$genome} = \%hash;

		}
		if ($error > 0) {die("Could not proceed. $error errors occured!\n");}
	}
	if ($data[0] =~ /^#/) {next;}
	
	# Fetch all files of
	open(OUT,">$line.faa");
	for (my $i = 3; $i < scalar(@data); $i++) {
		$data[$i] =~ s/,.*//;
		my $name = $paths[$i];
		$name =~ s/\....?$//;
		$name =~ s/\s//g;
		if (length($name) < 1) {die("Error at line $line, entry $i\n");}
#		print " $name";
		my $genome = $name;		
		$genome .= ".fna";
		if ($data[$i] eq "_GENOME_HIT_") {

		}
		elsif ($data[$i] eq "*") {
			# SET GENOME
			print REBLAST "$line\t$name\t$genomes_path/$genome\n";
#			print " -> *\n";
		}
		else {
		# open proteome
#		my %hash = fasta2hash("$proteins_path/$paths[$i]",1);
		if (!defined($genomes{$genome}{$data[$i]})) {die("Could not find '$data[$i]' in '$proteins_path/$paths[$i]'\n ");}
		print OUT ">$data[$i] $name\n$genomes{$genome}{$data[$i]}\n";
		}
#		print " -> ok\n";
	}
	close(OUT);
}
close(IN);
close(REBLAST);



# Reads a fasta file, returns two array pointers for header an sequence
# Access e.g. via $results[x]->[y]
#my %hash = fasta2hash($file);
sub fasta2hash {
	my $file = shift;
	my $cut = shift;
	if (!defined($cut)) {$cut = 0;}
	my %hash;
	open(FILE,"<$file") || die("fasta2hash(): Could not open file: $file\n");
	my $last_hash = "";
	while(<FILE>) {
		$_ =~ s/\r/\n/g;
		chomp;
		if ($_ =~ /^>/) {
			$_ =~ s/^>//;
			if ($cut) {
				$_ =~ s/ .*$//s;
			}
			$hash{$_} = "";
			$last_hash = $_;
			next;
		}
		$hash{$last_hash} .= $_;
	}
	close(FILE);
	return %hash;
}


